@@ -27,12 +27,27 @@ def _merge_tables(new_table: pd.DataFrame, old_table: pd.DataFrame) -> pd.DataFr
     return df
 
 
+def _remove_floats_where_isclose(diff: pd.Index, index: pd.Index) -> pd.Index:
+    diff_index_identical = np.zeros(len(diff), dtype=bool)
+    for i, idx in enumerate(diff):
+        where_isclose = np.ones(len(index), dtype=bool)
+        for l in range(len(idx)):
+            w = np.isclose(idx[l], index.get_level_values(l))
+            where_isclose = where_isclose * w
+        if where_isclose.any():
+            diff_index_identical[i] = True
+    return diff[~diff_index_identical]
+
+
 def _merge_indices(index1, index2) -> pd.Index:
     for name in index1.names:
         assert name in index2.names
         assert index1.get_level_values(name).dtype == index2.get_level_values(name).dtype
     assert len(index1.names) == len(index2.names)
-    merged = index1.append(index2.difference(index1))
+
+    diff = index2.difference(index1)
+    diff = _remove_floats_where_isclose(diff, index1)
+    merged = index1.append(diff)
     return merged
 
 
