@@ -27,9 +27,12 @@ class XYZExporter:
             folder: str,
             fiber_radius: float=0.1,
             name_non_filament_particles='non_filament',
-            name_links='link'
+            name_links='link',
+            frames: Union[List[int], None]=None
     ):
         trajectories_filaments = analyser.get_trajectories_filaments(minimum_image=True)
+        if frames is None:
+            frames = np.arange(len(trajectories_filaments))
 
         os.makedirs(folder, exist_ok=True)
 
@@ -38,28 +41,33 @@ class XYZExporter:
         fname_links = os.path.join(folder, name_links + '.xyz')
 
         XYZExporter.export_fibers(analyser, fname_fibers, fiber_radius,
-                                  trajectories_filaments)
+                                  trajectories_filaments, frames)
         XYZExporter.export_non_filament_particles(analyser, fname_non_fil,
-                                                  name_non_filament_particles)
+                                                  name_non_filament_particles, frames)
         XYZExporter.export_links(analyser, fname_links, name_links,
                                  trajectories_filaments,
-                                 radius=fiber_radius*1.5)
+                                 radius=fiber_radius*1.5,
+                                 frames=frames)
 
     @staticmethod
-    def export_fibers(analyser: Analyser,
-                      fname: str,
-                      fiber_radius: float, 
-                      trajectories: np.ndarray):
+    def export_fibers(
+            analyser: Analyser,
+            fname: str,
+            fiber_radius: float,
+            trajectories: np.ndarray,
+            frames: List[int]
+    ):
         
         fh = open(fname, 'wt')
 
+        trajectories = trajectories
         filaments_all = analyser.data_reader.get_filaments_all()
         periodic_box = analyser.data_reader.read_box_size()
         periodic_box = periodic_box[1] - periodic_box[0]
 
-        for t in range(len(trajectories)):
-            filaments = filaments_all[t]
-            traj_t = trajectories[t]
+        for f in frames:
+            filaments = filaments_all[f]
+            traj_t = trajectories[f]
 
             n_particles = 0
             block_xyz = ""
@@ -75,18 +83,24 @@ class XYZExporter:
         fh.close()
 
     @staticmethod
-    def export_non_filament_particles(analyser: Analyser, fname: str, label: str,
-                                      particle_range: Tuple[int, int]=None):
+    def export_non_filament_particles(
+            analyser: Analyser,
+            fname: str,
+            label: str,
+            frames: List[int],
+            particle_range: Tuple[int, int]=None,
+    ):
         trajectories = analyser.get_trajectories_non_filament(minimum_image=True)
         if particle_range is not None:
             trajectories = trajectories[:, particle_range[0]:particle_range[1]]
 
         fh = open(fname, 'wt')
 
-        for traj_t in trajectories:
-            n_particles = len(traj_t)
+        for f in frames:
+            traj_f = trajectories[f]
+            n_particles = len(traj_f)
             block_xyz = ""
-            for p in traj_t:
+            for p in traj_f:
                 block_xyz += f"{label} {p[0]:.2f} {p[1]:.2f} {p[2]:.2f}\n"
 
             block_xyz = "{}\n\n".format(n_particles) + block_xyz
@@ -96,7 +110,7 @@ class XYZExporter:
 
     @staticmethod
     def export_links(analyser: Analyser, fname: str, label: str, 
-                     trajectories: np.ndarray, radius: float):
+                     trajectories: np.ndarray, radius: float, frames: List[int]):
 
         periodic_box = analyser.data_reader.read_box_size()
         periodic_box = periodic_box[1] - periodic_box[0]
@@ -105,9 +119,9 @@ class XYZExporter:
 
         fh = open(fname, 'wt')
 
-        for t in range(len(trajectories)):
-            traj_t = trajectories[t]
-            links_t = links[t]
+        for f in frames:
+            traj_t = trajectories[f]
+            links_t = links[f]
 
             w = np.where(links_t[:, 2] != -1)[0]
             pairs = []
@@ -297,6 +311,7 @@ class XYZExporter:
             f.write('{} {} {} {}\n'.format(*xyz_i))
         f.close()
 
+
 def get_angles(v: np.ndarray) -> Tuple[float, float]:
     """
     Get angles theta, phi in spherical coordinates of vector v.
