@@ -15,6 +15,7 @@ class Bead:
 
 class Filament:
 
-    def __init__(self, items: List[int], motors: List[int]):
+    def __init__(self, filament_id: int, items: List[int], motors: List[int]):
+        self.id = filament_id
         self.items = items
         self.motors = motors
